==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/share/black_dialogs_cs.lua <==

dialogId("smrt-v-0", "font_big", "Oh, shoot!")
dialogStr("No a je to v ...")


dialogId("smrt-m-psst", "font_small", "Shhh, children can be playing this game!")
dialogStr("Pššt, mohou to hrát i děti!")


dialogId("smrt-v-1", "font_big", "Darn.")
dialogStr("Zatraceně.")


dialogId("smrt-v-2", "font_big", "Dang!")
dialogStr("Shit!")


dialogId("smrt-v-3", "font_big", "Scheisse!")
dialogStr("Scheisse!")


dialogId("smrt-v-4", "font_big", "Hmmm... and now I am alone.")
dialogStr("Hmmm... a jsem sám.")


dialogId("smrt-v-5", "font_big", "Did she know she has such a sexy skeleton?")
dialogStr("Jestlipak věděla, že má tak sexy kostru?")


dialogId("smrt-v-6", "font_big", "Terrible end of the little fish...")
dialogStr("Strašlivý konec pro malou rybku...")


dialogId("smrt-v-7", "font_big", "What can be the constant of decay of the fish skeleton?")
dialogStr("Jaký je asi poločas rozpadu rybí kostřičky?")


dialogId("smrt-m-0", "font_small", "So much for him.")
dialogStr("No, a je to.")


dialogId("smrt-m-1", "font_small", "Oh, nooo.")
dialogStr("Ach nééé.")


dialogId("smrt-m-2", "font_small", "And now I am alone.")
dialogStr("A jsem tady sama.")


dialogId("smrt-m-3", "font_small", "That must have hurt.")
dialogStr("To muselo ale bolet.")


dialogId("smrt-m-4", "font_small", "He didn`t deserve such a terrible end...")
dialogStr("Chudák, takový konec si nezasloužil...")


dialogId("smrt-m-5", "font_small", "So, let`s start again...")
dialogStr("Tak znovu...")


dialogId("smrt-x-obe", "font_parrot", "Aye, caramba!")
dialogStr("Oj, karamba!")


dialogId("smrt-v-obe", "font_big", "But there is no parrot here!")
dialogStr("Tady přeci papoušek není!")


dialogId("smrt-m-obe", "font_small", "Shut up, you are dead.")
dialogStr("Mlč, jsi mrtvý.")


dialogId("smrt-m-6", "font_small", "And I never told him I loved him.")
dialogStr("Ani jsem mu nestačila říci, že ho miluji.")


dialogId("smrt-m-restart", "font_small", "Luckily, it`s possible to restart the level.")
dialogStr("Naštěstí je možno místnost restartovat.")


dialogId("smrt-v-restart", "font_big", "Fortunately, we can restart the level.")
dialogStr("Ještě že je možno místnost restartovat.")


dialogId("smrt-v-zahrobi", "font_big", "Restart the level! The afterlife is too tedious.")
dialogStr("Restartuj místnost! Posmrtný život není moc zábavný.")


dialogId("smrt-m-zahrobi", "font_small", "Restart the level! This afterlife is too scary.")
dialogStr("Restartuj místnost. Tady v záhrobí je to hrozně strašidelné.")


dialogId("smrt-v-posmrtny", "font_big", "Hellooo? Can you hear me hereafter? Is there life after death?")
dialogStr("Halóóó. Slyšíš mě tam někde v záhrobí? Existuje posmrtný život?")


dialogId("smrt-m-posmrtny", "font_small", "I don`t know. I don`t think so.")
dialogStr("Nevím. Myslím, že ne.")


dialogId("smrt-m-autorest", "font_small", "I am not going to solve it alone. Don`t trouble yourself with restart, I`ll do it myself.")
dialogStr("Sama to řešit nebudu. Ani se nemusíš obtěžovat s restartem, udělám to sama.")


dialogId("smrt-v-autorest", "font_big", "And she is gone. I`m sure you liked her as much as I did. Certainly, you have nothing against restarting the level.")
dialogStr("Je pryč. Určitě sis ji za tu dobu taky tak oblíbil jako já. Takže nemáš nic proti restartu.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/share/black_dialogs_cs.lua <==

dialogId("smrt-v-0", "font_big", "Oh, shoot!")
dialogStr("No a je to v ...")


dialogId("smrt-m-psst", "font_small", "Shhh, children can be playing this game!")
dialogStr("Pššt, mohou to hrát i děti!")


dialogId("smrt-v-1", "font_big", "Darn.")
dialogStr("Zatraceně.")


dialogId("smrt-v-2", "font_big", "Dang!")
dialogStr("Shit!")


dialogId("smrt-v-3", "font_big", "Scheisse!")
dialogStr("Scheisse!")


dialogId("smrt-v-4", "font_big", "Hmmm... and now I am alone.")
dialogStr("Hmmm... a jsem sám.")


dialogId("smrt-v-5", "font_big", "Did she know she has such a sexy skeleton?")
dialogStr("Jestlipak věděla, že má tak sexy kostru?")


dialogId("smrt-v-6", "font_big", "Terrible end of the little fish...")
dialogStr("Strašlivý konec pro malou rybku...")


dialogId("smrt-v-7", "font_big", "What can be the constant of decay of the fish skeleton?")
dialogStr("Jaký je asi poločas rozpadu rybí kostřičky?")


dialogId("smrt-m-0", "font_small", "So much for him.")
dialogStr("No, a je to.")


dialogId("smrt-m-1", "font_small", "Oh, nooo.")
dialogStr("Ach nééé.")


dialogId("smrt-m-2", "font_small", "And now I am alone.")
dialogStr("A jsem tady sama.")


dialogId("smrt-m-3", "font_small", "That must have hurt.")
dialogStr("To muselo ale bolet.")


dialogId("smrt-m-4", "font_small", "He didn’t deserve such a terrible end...")
dialogStr("Chudák, takový konec si nezasloužil...")


dialogId("smrt-m-5", "font_small", "So, let’s start again...")
dialogStr("Tak znovu...")


dialogId("smrt-x-obe", "font_parrot", "Aye, caramba!")
dialogStr("Oj, karamba!")


dialogId("smrt-v-obe", "font_big", "But there is no parrot here!")
dialogStr("Tady přeci papoušek není!")


dialogId("smrt-m-obe", "font_small", "Shut up, you are dead.")
dialogStr("Mlč, jsi mrtvý.")


dialogId("smrt-m-6", "font_small", "And I never told him I loved him.")
dialogStr("Ani jsem mu nestačila říci, že ho miluji.")


dialogId("smrt-m-restart", "font_small", "Luckily, it’s possible to restart the level.")
dialogStr("Naštěstí je možno místnost restartovat.")


dialogId("smrt-v-restart", "font_big", "Fortunately, we can restart the level.")
dialogStr("Ještě že je možno místnost restartovat.")


dialogId("smrt-v-zahrobi", "font_big", "Restart the level! The afterlife is too tedious.")
dialogStr("Restartuj místnost! Posmrtný život není moc zábavný.")


dialogId("smrt-m-zahrobi", "font_small", "Restart the level! This afterlife is too scary.")
dialogStr("Restartuj místnost. Tady v záhrobí je to hrozně strašidelné.")


dialogId("smrt-v-posmrtny", "font_big", "Hellooo? Can you hear me hereafter? Is there life after death?")
dialogStr("Halóóó. Slyšíš mě tam někde v záhrobí? Existuje posmrtný život?")


dialogId("smrt-m-posmrtny", "font_small", "I don’t know. I don’t think so.")
dialogStr("Nevím. Myslím, že ne.")


dialogId("smrt-m-autorest", "font_small", "I am not going to solve it alone. Don’t trouble yourself with restart, I’ll do it myself.")
dialogStr("Sama to řešit nebudu. Ani se nemusíš obtěžovat s restartem, udělám to sama.")


dialogId("smrt-v-autorest", "font_big", "And she is gone. I’m sure you liked her as much as I did. Certainly, you have nothing against restarting the level.")
dialogStr("Je pryč. Určitě sis ji za tu dobu taky tak oblíbil jako já. Takže nemáš nic proti restartu.")
